package com.ruoyi.web.modules.trading.service;

import java.util.List;
import com.ruoyi.web.modules.trading.domain.BizTradeOrder;

/**
 * 交易订单服务
 */
public interface IBizTradeOrderService
{
    BizTradeOrder selectBizTradeOrderById(Long id);

    List<BizTradeOrder> selectBizTradeOrderList(BizTradeOrder query);

    int insertBizTradeOrder(BizTradeOrder row);

    int updateBizTradeOrder(BizTradeOrder row);

    int deleteBizTradeOrderByIds(Long[] ids, String updateBy);

    List<String> selectSupplierEarTags(Long supplierId);

    BizTradeOrder completePay(BizTradeOrder payRequest, String operator);
}
